@@ -43,7 +43,8 @@ use safe_network::routing::create_test_used_space_and_root_storage;
 use safe_network::messaging::{
     data::Error::FailedToWriteFile, system::SystemMsg, DstLocation, MessageId,
 };
-use safe_network::routing::{Cache, Config, Event as RoutingEvent, NodeElderChange, Routing};
+use safe_network::routing::{Config, Event as RoutingEvent, NodeElderChange, Routing};
+use safe_network::types::Cache;
 
 // Minimal delay between two consecutive prints of the network status.
 const MIN_PRINT_DELAY: Duration = Duration::from_millis(500);
