@@ -32,7 +32,7 @@ const DB_DIR: &str = "db";
 
 /// `KvStore` is a store of keys and values into a Sled db, while maintaining a maximum disk
 /// usage to restrict storage.
-#[derive(Clone)]
+#[derive(Clone, Debug)]
 pub(crate) struct KvStore<K, V> {
     // tracks space used.
     used_space: UsedSpace,
@@ -132,7 +132,7 @@ impl<K: Key, V: Value + Send + Sync> KvStore<K, V> {
     /// an IO error, it returns `Error::Io`.
     ///
     /// If a value with the same id already exists, it will be overwritten.
-    #[allow(unused)] // the use of this is anticipated to be implemented shortly
+    #[allow(unused)] // this will soon be used
     pub(crate) async fn store_batch(&self, values: &[V]) -> Result<()> {
         info!("Writing batch");
         use rayon::prelude::*;
@@ -147,7 +147,7 @@ impl<K: Key, V: Value + Send + Sync> KvStore<K, V> {
                 let key = value.key().to_db_key()?;
                 Ok((key, serialised_value))
             })
-            .partition(|r| r.is_err());
+            .partition(|r| r.is_ok());
 
         if !err_results.is_empty() {
             for e in err_results {
@@ -179,7 +179,7 @@ impl<K: Key, V: Value + Send + Sync> KvStore<K, V> {
                 Ok(())
             }
             Err(e) => {
-                info!("Writing batch failed!");
+                warn!("Writing batch failed!");
                 Err(Error::Sled(e))
             }
         }
