@@ -217,7 +217,7 @@ impl WireMsg {
         match &self.header.msg_envelope.msg_kind {
             MsgKind::NodeAuthMsg(node_signed) => Some(node_signed.section_pk),
             MsgKind::NodeBlsShareAuthMsg(bls_share_signed) => Some(bls_share_signed.section_pk),
-            MsgKind::SectionAuthMsg(section_signed) => Some(section_signed.section_pk),
+            MsgKind::SectionAuthMsg(section_signed) => Some(section_signed.sig.public_key),
             _ => None,
         }
     }
@@ -239,7 +239,7 @@ mod tests {
     use super::*;
     use crate::{
         messaging::{
-            data::{ChunkRead, DataQuery, ServiceMsg, StorageLevel},
+            data::{DataQuery, ServiceMsg, StorageLevel},
             system::{NodeCmd, SystemMsg},
             AuthorityProof, MessageId, NodeAuth, ServiceAuth,
         },
@@ -316,9 +316,7 @@ mod tests {
 
         let msg_id = MessageId::new();
 
-        let client_msg = ServiceMsg::Query(DataQuery::Chunk(ChunkRead::Get(
-            ChunkAddress::Private(XorName::random()),
-        )));
+        let client_msg = ServiceMsg::Query(DataQuery::GetChunk(ChunkAddress(XorName::random())));
 
         let payload = WireMsg::serialize_msg_payload(&client_msg)?;
         let auth = ServiceAuth {
