@@ -106,7 +106,7 @@ pub(crate) fn convert_to_error_message(error: Error) -> ErrorMessage {
     match error {
         Error::InvalidOperation(msg) => ErrorMessage::InvalidOperation(msg),
         Error::InvalidMessage(_, msg) => ErrorMessage::InvalidOperation(msg),
-        Error::InvalidOwner(key) => ErrorMessage::InvalidOwners(key),
+        Error::InvalidOwner(key) => ErrorMessage::InvalidOwner(key),
         Error::NoSuchData(address) => ErrorMessage::DataNotFound(address),
         Error::TempDirCreationFailed(_) => ErrorMessage::FailedToWriteFile,
         Error::DataExists => ErrorMessage::DataExists,
