@@ -7,15 +7,12 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 use crate::messaging::{
-    data::{
-        ChunkRead, ChunkWrite, DataCmd, DataExchange, DataQuery, QueryResponse, ServiceError,
-        ServiceMsg,
-    },
-    node::NodeMsg,
-    AuthorityProof, DstLocation, EndUser, MessageId, ServiceAuth,
+    data::{DataExchange, ServiceError, ServiceMsg, StorageLevel},
+    system::SystemMsg,
+    DstLocation, MessageId,
 };
 use crate::routing::Prefix;
-use crate::types::{Chunk, PublicKey};
+use crate::types::PublicKey;
 use std::collections::BTreeSet;
 use xor_name::XorName;
 
@@ -39,33 +36,10 @@ pub(super) type NodeDuties = Vec<NodeDuty>;
 #[allow(clippy::large_enum_variant)]
 #[derive(Debug)]
 pub enum NodeDuty {
-    ReadChunk {
-        msg_id: MessageId,
-        read: ChunkRead,
-        auth: AuthorityProof<ServiceAuth>,
-    },
-    WriteChunk {
-        msg_id: MessageId,
-        write: ChunkWrite,
-        auth: AuthorityProof<ServiceAuth>,
-    },
-    ProcessRepublish {
-        msg_id: MessageId,
-        chunk: Chunk,
-    },
-    /// Run at data-section Elders on receiving the result of
-    /// read operations from Adults
-    RecordAdultReadLiveness {
-        response: QueryResponse,
-        correlation_id: MessageId,
-        src: XorName,
-    },
     Genesis,
     EldersChanged {
         /// Our section prefix.
         our_prefix: Prefix,
-        /// Our section public key.
-        our_key: PublicKey,
         /// The new Elders.
         new_elders: BTreeSet<XorName>,
         /// Oldie or newbie?
@@ -107,12 +81,12 @@ pub enum NodeDuty {
         name: XorName,
         age: u8,
     },
-    /// Storage reaching max capacity.
-    ReachingMaxCapacity,
     /// Increment count of full nodes in the network
-    IncrementFullNodeCount {
-        /// Node ID of node that reached max capacity.
+    SetStorageLevel {
+        /// Node ID of node that is reporting capacity.
         node_id: PublicKey,
+        /// The storage level the node claims to be at.
+        level: StorageLevel,
     },
     /// Sets joining allowed to true or false.
     SetNodeJoinsAllowed(bool),
@@ -124,32 +98,10 @@ pub enum NodeDuty {
     /// Send the same request to each individual node.
     SendToNodes {
         msg_id: MessageId,
-        msg: NodeMsg,
+        msg: SystemMsg,
         targets: BTreeSet<XorName>,
         aggregation: bool,
     },
-    /// Process read of data
-    ProcessRead {
-        msg_id: MessageId,
-        query: DataQuery,
-        auth: AuthorityProof<ServiceAuth>,
-        origin: EndUser,
-    },
-    /// Process write of data
-    ProcessWrite {
-        msg_id: MessageId,
-        cmd: DataCmd,
-        auth: AuthorityProof<ServiceAuth>,
-        origin: EndUser,
-    },
-    /// Receive a chunk that is being replicated.
-    /// This is run at an Adult (the new holder).
-    ReplicateChunk {
-        msg_id: MessageId,
-        chunk: Chunk,
-    },
-    /// Create proposals to vote unresponsive nodes as offline
-    ProposeOffline(Vec<XorName>),
     NoOp,
 }
 
@@ -167,7 +119,6 @@ impl From<NodeDuty> for NodeDuties {
 
 #[derive(Debug, Clone)]
 pub struct OutgoingMsg {
-    pub id: MessageId,
     pub msg: MsgType,
     pub dst: DstLocation,
     pub aggregation: bool,
@@ -176,7 +127,7 @@ pub struct OutgoingMsg {
 #[derive(Debug, Clone)]
 #[allow(clippy::large_enum_variant)]
 pub enum MsgType {
-    Node(NodeMsg),
+    Node(SystemMsg),
     Client(ServiceMsg),
 }
 
