@@ -47,7 +47,7 @@ pub(crate) enum Command {
         known_keys: Vec<BlsPublicKey>,
     },
     /// Handle verified node message after aggregation either directly or notify via event listener
-    HandleVerifiedNodeNonDataMessage {
+    HandleBlockingMessage {
         sender: SocketAddr,
         msg_id: MessageId,
         msg: SystemMsg,
@@ -56,11 +56,12 @@ pub(crate) enum Command {
         known_keys: Vec<BlsPublicKey>,
     },
     /// Handle Node data messages directly
-    HandleVerifiedNodeDataMessage {
+    HandleNonBlockingMessage {
         msg_id: MessageId,
         msg: SystemMsg,
         msg_authority: NodeMsgAuthority,
         dst_location: DstLocation,
+        sender: SocketAddr,
     },
     /// Handle a timeout previously scheduled with `ScheduleTimeout`.
     HandleTimeout(u64),
