@@ -13,7 +13,11 @@ use crate::messaging::{
 };
 use crate::routing::{peer::PeerUtils, SectionAuthorityProviderUtils};
 use itertools::Itertools;
-use std::{cmp::Ordering, collections::btree_map::Entry, mem};
+use std::{
+    cmp::Ordering,
+    collections::{btree_map::Entry, BTreeSet},
+    mem,
+};
 use xor_name::{Prefix, XorName};
 
 /// Container for storing information about members of our section.
@@ -38,6 +42,7 @@ pub(crate) trait SectionPeersUtils {
         &self,
         elder_size: usize,
         current_elders: &SectionAuthorityProvider,
+        excluded_names: &BTreeSet<XorName>,
     ) -> Vec<Peer>;
 
     /// Returns the candidates for elders out of all nodes matching the prefix.
@@ -46,6 +51,7 @@ pub(crate) trait SectionPeersUtils {
         prefix: &Prefix,
         elder_size: usize,
         current_elders: &SectionAuthorityProvider,
+        excluded_names: &BTreeSet<XorName>,
     ) -> Vec<Peer>;
 
     /// Returns whether the given peer is a joined member of our section.
@@ -102,14 +108,17 @@ impl SectionPeersUtils for SectionPeers {
         &self,
         elder_size: usize,
         current_elders: &SectionAuthorityProvider,
+        excluded_names: &BTreeSet<XorName>,
     ) -> Vec<Peer> {
         elder_candidates(
             elder_size,
             current_elders,
             self.members
-                .values()
-                .filter(|info| is_active(&info.value, current_elders))
-                .filter(|info| info.value.peer.is_reachable()),
+                .iter()
+                .filter(|(_, info)| is_active(&info.value, current_elders))
+                .filter(|(_, info)| info.value.peer.is_reachable())
+                .filter(|(name, _)| !excluded_names.contains(name))
+                .map(|(_, info)| info),
         )
     }
 
@@ -119,15 +128,18 @@ impl SectionPeersUtils for SectionPeers {
         prefix: &Prefix,
         elder_size: usize,
         current_elders: &SectionAuthorityProvider,
+        excluded_names: &BTreeSet<XorName>,
     ) -> Vec<Peer> {
         elder_candidates(
             elder_size,
             current_elders,
-            self.members.values().filter(|info| {
-                info.value.state == MembershipState::Joined
-                    && prefix.matches(info.value.peer.name())
-                    && info.value.peer.is_reachable()
-            }),
+            self.members
+                .iter()
+                .filter(|(_, info)| info.value.state == MembershipState::Joined)
+                .filter(|(name, _)| prefix.matches(name))
+                .filter(|(_, info)| info.value.peer.is_reachable())
+                .filter(|(name, _)| !excluded_names.contains(name))
+                .map(|(_, info)| info),
         )
     }
 
